#!/usr/bin/env python
"""This module collects as much information as possible that would be
useful for debugging Epidermis
Function debuginfo() should be used by gtkexcepthook"""
import sys, os
import const
import gconf
import traceback


def debuginfo():
    import handy
    import managepigments
    import pigments.pigment
    info = "Additional debugging information follows:\n"
    info += "Epidermis version: %s\n" % const.VERSION
    info += "debuginfo.py path: " + __file__ + "\n\n"
    
    info += "Python version: %s\n" % sys.version
    
    info += "System info: "
    pop = os.popen("lsb_release -d")
    for line in pop.readlines():
        info += line
    info += open("/proc/version", 'r').readline()
    
    # get gconf settings
    info += "\n"
    client = gconf.client_get_default()
    for string in ("/apps/epidermis/repo_url", "/apps/epidermis/providers_url", "/apps/epidermis/repo_last_modified",
    "/apps/epidermis/repo_etag"):
        info += "gconf:%s = '%s'\n" % (string, client.get_string(string))
    
    # pigments
    info += "\nexamining installed pigments, only pigments which don't return STATE_INSTALLED are listed\n"
    pigms = {}
    for pt in const.PIGMENT_TYPES:
        try:
            pigms[pt], excps = managepigments.find_pigments(pt)
            for exc in excps:
                info += "\n".join(traceback.format_exception(exc[0], exc[1], exc[2])) + "\n"
            for pigment in pigms[pt]:
                if pigment.get_state() != pigments.pigment.STATE_INSTALLED:
                    info += "%s is %s\n" %(str(pigment), pigment.debug_get_state_str())
        except:
            info += traceback.format_exc() + "\n"
    info += "--end pigments\n"
    
    info += "--end of debugging information"
    
    
    return info
    

if __name__ == "__main__":
    print debuginfo()