#!/usr/bin/env python
# Copyright 2008-2009 David D Lowe
# released under the GPLv3

from pigment import PigmentType, Pigment
from pigment_more import FileBasedPigment, FileBasedPigmentType
import pigment
import os, sys
import subprocess
import gtk
from glob import glob
if __name__ == "__main__" or 'pychecker' in sys.argv[0]:
    sys.path.append("..")
import handy
import ep_exceptions
import hashlib
from gettext import gettext as _


class GrubType(FileBasedPigmentType):
    humanName = {"en":"Grub"}
    humanPluralName = {"en":"Grub"}
    codeName = "grub"
    abbreviation = "gr"
    directoryName = "grub"
    canGeneratePreview = True
    
    attachmentTypeHelp = _("The theme file should be a compressed xpm image file with the extension xpm.gz")
    
    publicBaseDir = "/boot/grub/splashimages"
    personalBaseDir = ""
        
    def get_Pigment(self):
        return Grub

class Grub(FileBasedPigment):
    
    
    def __init__(self):
        FileBasedPigment.__init__(self)
        self.type = GrubType()
    
    def activate(self, progressCallback=None, shell=None):
        if progressCallback is None:
            progressCallback = lambda(a1): False
        if progressCallback(0.0): return
        if os.path.exists("/boot/grub/splash.xpm.gz"):
            shell.do(["cp", "-f", "/boot/grub/splash.xpm.gz", "/boot/grub/splash.xpm.gz.epidermis.bak"])
            shell.do(["rm", "/boot/grub/splash.xpm.gz"])
        if progressCallback(0.25): return
        shell.do(["ln", "-s", os.path.join(self.type.publicBaseDir,self.attFilename), "/boot/grub/splash.xpm.gz"])
        if progressCallback(0.5): return
        shell.do(["update-grub"])
        progressCallback(1.0)
    
    def is_activated(self):
        """Returns whether this pigment is applied. To check if the effects
        have been activated regardless of Epidermis' pigments, use is_meat_activated"""
        return self.is_meat_activated()

    def is_attachment_correct(self, attachmentIndex=None):
        if FileBasedPigment.is_attachment_correct(self, attachmentIndex):
            if attachmentIndex is None:
                attachmentIndex = 0
            extension = self.attachments[attachmentIndex].split(".")[-2:]
            if not (extension[0], extension[1]) == ("xpm","gz"):
                return False
            return True
        else: return False
    
    def is_meat_activated(self):
        """Returns whether the meat of this pigment or similar to it is activated"""
        # TODO: finish is_meat_activated
        (md1, md2) = (hashlib.md5(), hashlib.md5())
        try:
            f1 = file(self.attPath, 'rb')
            f2 = file("/boot/grub/splash.xpm.gz", 'rb')
        except:
            return False
        for mm, ff in ((md1, f1), (md2, f2)):
            ss = ff.read(8096)
            if not ss:
                break
            mm.update(ss)
        return md1 == md2
    
    def generate_preview(self):
        if not os.path.exists(self.attPath):
            return None
        subprocess.call(["mkdir",  "-p",  "/tmp/epidermis"])
        subprocess.call(["cp", self.attPath,  "/tmp/epidermis/grub-preview.xpm.gz"])
        res = subprocess.call(["gunzip",  "-f","/tmp/epidermis/grub-preview.xpm.gz"],  cwd="/tmp/epidermis")
        if res == 1:
            subprocess.call(["mv",  "grub-preview.xpm.gz",  "grub-preview.xpm"],  cwd="/tmp/epidermis")
        try:
            pb = gtk.gdk.pixbuf_new_from_file_at_size("/tmp/epidermis/grub-preview.xpm", 100, 75)
        except:
            import traceback
            traceback.print_exc()
            return None
        if pb is None:
            return None
        else:
            self.preview = pb
            return pb
    
    def does_activation_require_root(self):
        """Returns whether the activation requires root rights.
        If it does, the pigment object will need a pexpect bash shell as root
        to be passed to some of its methods"""
        return True
    
    def get_display_data(self, index=0):
        """Returns the object of index to be added to a gtk.ListStore, this
        could be a string, a gtk.gdk.Pixbuf or a custom widget, it should
        be rendered using type.create_cell_renderer"""
        return


if __name__ == "__main__":
    main()
